# nWave Reference

Auto-generated documentation for 32 agents, 23 commands, 140 skills, and 9 templates.

## Contents

- [Agents](agents/index.md) (32)
- [Commands](commands/index.md) (23)
- [Skills](skills/index.md) (140)
- [Templates](templates/index.md) (9)
